@@ -1,7 +1,7 @@
 #' @export
 #' @rdname Task
 #' @family costsens
-makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blocking = NULL, fixup.data = "warn", check.data = TRUE) {
+makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blocking = NULL, coordinates = NULL, fixup.data = "warn", check.data = TRUE) {
   assertString(id)
   assertDataFrame(data)
   assertChoice(fixup.data, choices = c("no", "quiet", "warn"))
@@ -18,7 +18,10 @@ makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blockin
     if (is.null(colnames(costs)))
       colnames(costs) = stri_paste("y", seq_col(costs))
   }
-  task = makeSupervisedTask("costsens", data, target, weights, blocking, fixup.data = fixup.data, check.data = check.data)
+  task = makeSupervisedTask("costsens", data = data, target = target,
+                            weights = weights, blocking = blocking,
+                            coordinates = coordinates, fixup.data = fixup.data,
+                            check.data = check.data)
 
   if (check.data) {
     assertMatrix(costs, any.missing = FALSE, col.names = "strict")
@@ -30,12 +33,14 @@ makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blockin
       stopf("The name '..y..' is currently reserved for costsens tasks. You can use it neither for features nor labels!")
   }
 
-  task$task.desc = makeCostSensTaskDesc(id, data, target, blocking, costs)
+  task$task.desc = makeCostSensTaskDesc(id, data, target, blocking, costs, coordinates)
   addClasses(task, "CostSensTask")
 }
 
-makeCostSensTaskDesc = function(id, data, target, blocking, costs) {
-  td = makeTaskDescInternal("costsens", id, data, target, weights = NULL, blocking = blocking)
+#' @export
+#' @rdname makeTaskDesc
+makeCostSensTaskDesc = function(id, data, target, blocking, costs, coordinates) {
+  td = makeTaskDescInternal("costsens", id, data, target, weights = NULL, blocking = blocking, coordinates)
   td$class.levels = colnames(costs)
   td$costs = costs
   return(addClasses(td, c("CostSensTaskDesc", "SupervisedTaskDesc")))
