@@ -2,7 +2,7 @@
 #' @rdname FeatSelControl
 makeFeatSelControlExhaustive = function(same.resampling.instance = TRUE,
   maxit = NA_integer_, max.features = NA_integer_, tune.threshold = FALSE, tune.threshold.args = list(),
-  log.fun = NULL) {
+  log.fun = "default") {
 
   makeFeatSelControl(same.resampling.instance = same.resampling.instance,
     maxit = maxit, max.features = max.features,
