@@ -1,31 +1,32 @@
-.FilterRegister = new.env()
+.FilterRegister = new.env()  # nolint
 
 #' Create a feature filter.
 #'
 #' Creates and registers custom feature filters. Implemented filters
-#' can be listed with \code{\link{listFilterMethods}}. Additional
-#' documentation for the \code{fun} parameter specific to each filter can
+#' can be listed with [listFilterMethods]. Additional
+#' documentation for the `fun` parameter specific to each filter can
 #' be found in the description.
 #'
-#' @param name [\code{character(1)}]\cr
+#' @param name (`character(1)`)\cr
 #'  Identifier for the filter.
-#' @param desc [\code{character(1)}]\cr
+#' @param desc (`character(1)`)\cr
 #'  Short description of the filter.
-#' @param pkg [\code{character(1)}]\cr
+#' @param pkg (`character(1)`)\cr
 #'  Source package where the filter is implemented.
-#' @param supported.tasks [\code{character}]\cr
+#' @param supported.tasks ([character])\cr
 #'  Task types supported.
-#' @param supported.features [\code{character}]\cr
+#' @param supported.features ([character])\cr
 #'  Feature types supported.
-#' @param fun [\code{function(task, nselect, ...}]\cr
+#' @param fun (`function(task, nselect, ...`)\cr
 #'  Function which takes a task and returns a named numeric vector of scores,
-#'  one score for each feature of \code{task}.
+#'  one score for each feature of `task`.
 #'  Higher scores mean higher importance of the feature.
-#'  At least \code{nselect} features must be calculated, the remaining may be
-#'  set to \code{NA} or omitted, and thus will not be selected.
+#'  At least `nselect` features must be calculated, the remaining may be
+#'  set to `NA` or omitted, and thus will not be selected.
 #'  the original order will be restored if necessary.
 #' @return Object of class \dQuote{Filter}.
 #' @export
+#' @family filter
 makeFilter = function(name, desc, pkg, supported.tasks, supported.features, fun) {
   assertString(name)
   assertString(desc)
@@ -49,20 +50,21 @@ makeFilter = function(name, desc, pkg, supported.tasks, supported.features, fun)
 #'
 #' Returns a subset-able dataframe with filter information.
 #'
-#' @param desc [\code{logical(1)}]\cr
+#' @param desc (`logical(1)`)\cr
 #'  Provide more detailed information about filters.
-#'  Default is \code{TRUE}.
-#' @param tasks [\code{logical(1)}]\cr
+#'  Default is `TRUE`.
+#' @param tasks (`logical(1)`)\cr
 #'  Provide information on supported tasks.
-#'  Default is \code{FALSE}.
-#' @param features [\code{logical(1)}]\cr
+#'  Default is `FALSE`.
+#' @param features (`logical(1)`)\cr
 #'  Provide information on supported features.
-#'  Default is \code{FALSE}.
-#' @param include.deprecated [\code{logical(1)}]\cr
+#'  Default is `FALSE`.
+#' @param include.deprecated (`logical(1)`)\cr
 #'  Should deprecated filter methods be included in the list.
-#'  Default is \code{FALSE}.
-#' @return [\code{data.frame}].
+#'  Default is `FALSE`.
+#' @return ([data.frame]).
 #' @export
+#' @family filter
 listFilterMethods = function(desc = TRUE, tasks = FALSE, features = FALSE, include.deprecated = FALSE) {
   tag2df = function(tags, prefix = "") {
     unique.tags = sort(unique(unlist(tags)))
@@ -93,7 +95,7 @@ listFilterMethods = function(desc = TRUE, tasks = FALSE, features = FALSE, inclu
   if (include.deprecated)
     df$deprecated = deprecated
   else
-    df = df[!deprecated,]
+    df = df[!deprecated, ]
   res = setRowNames(sortByCol(df, "id"), NULL)
   addClasses(res, "FilterMethodsList")
 }
@@ -129,7 +131,7 @@ makeFilter(
   supported.features = c("numerics", "ordered"),
   fun = function(task, nselect, ...) {
     if (inherits(task, "SurvTask")) {
-      data = getTaskData(task, target.extra = TRUE, recode.target = "rcens")
+      data = getTaskData(task, target.extra = TRUE, recode.target = "surv")
       data = cbind(..surv = data$target, data$data)
       target.ind = 1L
     } else {
@@ -171,9 +173,9 @@ makeFilter(
 
 #' Filter \dQuote{randomForestSRC.rfsrc} computes the importance of random forests
 #' fitted in package \pkg{randomForestSRC}. The concrete method is selected via
-#' the \code{method} parameter. Possible values are \code{permute} (default), \code{random},
-#' \code{anti}, \code{permute.ensemble}, \code{random.ensemble}, \code{anti.ensemble}.
-#' See the VIMP section in the docs for \code{\link[randomForestSRC]{rfsrc}} for
+#' the `method` parameter. Possible values are `permute` (default), `random`,
+#' `anti`, `permute.ensemble`, `random.ensemble`, `anti.ensemble`.
+#' See the VIMP section in the docs for [randomForestSRC::rfsrc] for
 #' details.
 #'
 #' @rdname makeFilter
@@ -201,13 +203,13 @@ rf.importance = makeFilter(
 .FilterRegister[["rf.importance"]] = rf.importance
 .FilterRegister[["rf.importance"]]$desc = "Importance of random forests fitted in package 'randomForestSRC'. Importance is calculated using argument 'permute'. (DEPRECATED)"
 .FilterRegister[["rf.importance"]]$fun = function(...) {
-  .Deprecated(old = "Filter 'rf.importance'", new = "Filter 'randomForestSRC.rfsrc'")
+  .Deprecated(old = "Filter 'rf.importance'", new = "Filter 'randomForest.importance' (package randomForest) or Filter 'randomForestSRC.rfsrc' (package randomForestSRC)")
   .FilterRegister[["randomForestSRC.rfsrc"]]$fun(...)
 }
 
 #' Filter \dQuote{randomForestSRC.var.select} uses the minimal depth variable
-#' selection proposed by Ishwaran et al. (2010) (\code{method = "md"}) or a
-#' variable hunting approach (\code{method = "vh"} or \code{method = "vh.vimp"}).
+#' selection proposed by Ishwaran et al. (2010) (`method = "md"`) or a
+#' variable hunting approach (`method = "vh"` or `method = "vh.vimp"`).
 #' The minimal depth measure is the default.
 #'
 #' @rdname makeFilter
@@ -251,23 +253,23 @@ makeFilter(
     p = getTaskNFeats(task)
     if (p < mtry)
       args$mtry = p
-    cforest_args = as.list(base::args(party::cforest))
-    cforest_args = args[names(args) %in% names(cforest_args)]
-    control_args = as.list(base::args(party::cforest_control))
-    control_args = args[names(args) %in% names(control_args)]
-    varimp_args = as.list(base::args(party::varimp))
-    varimp_args = args[names(args) %in% names(varimp_args)]
-    ctrl = do.call(party::cforest_unbiased, control_args)
+    cforest.args = as.list(base::args(party::cforest))
+    cforest.args = args[names(args) %in% names(cforest.args)]
+    control.args = as.list(base::args(party::cforest_control))
+    control.args = args[names(args) %in% names(control.args)]
+    varimp.args = as.list(base::args(party::varimp))
+    varimp.args = args[names(args) %in% names(varimp.args)]
+    ctrl = do.call(party::cforest_unbiased, control.args)
     fit = do.call(party::cforest, c(list(formula = getTaskFormula(task), data = getTaskData(task), controls = ctrl),
-                                    cforest_args))
-    im = do.call(party::varimp, c(list(obj = fit), varimp_args))
+                                    cforest.args))
+    im = do.call(party::varimp, c(list(obj = fit), varimp.args))
     im
   }
 )
 
-#' Filter \dQuote{randomForest.importance} makes use of the \code{\link[randomForest]{importance}}
+#' Filter \dQuote{randomForest.importance} makes use of the [randomForest::importance]
 #' from package \pkg{randomForest}. The importance measure to use is selected via
-#' the \code{method} parameter:
+#' the `method` parameter:
 #' \describe{
 #'   \item{oob.accuracy}{Permutation of Out of Bag (OOB) data.}
 #'   \item{node.impurity}{Total decrease in node impurity.}
@@ -292,45 +294,37 @@ makeFilter(
   }
 )
 
-#' The Pearson correlation between each feature and the target is used as an indicator
-#' of feature importance. Rows with NA values are not taken into consideration.
+#' The absolute Pearson correlation between each feature and the target is used as an indicator of feature importance.
+#' Missing values are not taken into consideration in a pairwise fashion (see \dQuote{pairwise.complete.obs} in [cor]).
 #'
 #' @rdname makeFilter
 #' @name makeFilter
 makeFilter(
   name = "linear.correlation",
   desc = "Pearson correlation between feature and target",
-  pkg  = "Rfast",
+  pkg  = character(0L),
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
-    d = getTaskData(task, target.extra = TRUE)
-    y = Rfast::correls(d$target, d$data, type = "pearson")
-    for (i in which(is.na(y[, "correlation"]))) {
-      y[i, "correlation"] = cor(d$target, d$data[,i], use = "complete.obs")
-    }
-    setNames(abs(y[, "correlation"]), getTaskFeatureNames(task))
+    data = getTaskData(task, target.extra = TRUE)
+    abs(cor(as.matrix(data$data), data$target, use = "pairwise.complete.obs", method = "pearson")[, 1L])
   }
 )
 
-#' The Spearman correlation between each feature and the target is used as an indicator
-#' of feature importance. Rows with NA values are not taken into consideration.
+#' The absolute Pearson correlation between each feature and the target is used as an indicator of feature importance.
+#' Missing values are not taken into consideration in a pairwise fashion (see \dQuote{pairwise.complete.obs} in [cor]).
 #'
 #' @rdname makeFilter
 #' @name makeFilter
 makeFilter(
   name = "rank.correlation",
   desc = "Spearman's correlation between feature and target",
-  pkg  = "Rfast",
+  pkg  = character(0L),
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
-    d = getTaskData(task, target.extra = TRUE)
-    y = Rfast::correls(d$target, d$data, type = "spearman")
-    for (i in which(is.na(y[, "correlation"]))) {
-      y[i, "correlation"] = cor(d$target, d$data[,i], use = "complete.obs", method = "spearman")
-    }
-    setNames(abs(y[, "correlation"]), getTaskFeatureNames(task))
+    data = getTaskData(task, target.extra = TRUE)
+    abs(cor(as.matrix(data$data), data$target, use = "pairwise.complete.obs", method = "spearman")[, 1L])
   }
 )
 
@@ -409,8 +403,8 @@ makeFilter(
 #' Filter \dQuote{relief} is based on the feature selection algorithm \dQuote{ReliefF}
 #' by Kononenko et al., which is a generalization of the orignal \dQuote{Relief}
 #' algorithm originally proposed by Kira and Rendell. Feature weights are initialized
-#' with zeros. Then for each instance \code{sample.size} instances are sampled,
-#' \code{neighbours.count} nearest-hit and nearest-miss neighbours are computed
+#' with zeros. Then for each instance `sample.size` instances are sampled,
+#' `neighbours.count` nearest-hit and nearest-miss neighbours are computed
 #' and the weight vector for each feature is updated based on these values.
 #'
 #' @references
@@ -449,17 +443,16 @@ makeFilter(
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
-    print(getTaskFormula(task))
     y = FSelector::oneR(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
   }
 )
 
 #' The \dQuote{univariate.model.score} feature filter resamples an \pkg{mlr}
-#' learner specified via \code{perf.learner} for each feature individually
+#' learner specified via `perf.learner` for each feature individually
 #' with randomForest from package \pkg{rpart} being the default learner.
-#' Further parameter are the resamling strategey \code{perf.resampling} and
-#' the performance measure \code{perf.measure}.
+#' Further parameter are the resamling strategey `perf.resampling` and
+#' the performance measure `perf.measure`.
 #'
 #' @rdname makeFilter
 #' @name makeFilter
@@ -516,21 +509,16 @@ univariate = makeFilter(
 makeFilter(
   name = "anova.test",
   desc = "ANOVA Test for binary and multiclass classification tasks",
-  pkg = "Rfast",
-  supported.tasks = c("classif"),
-  supported.features = c("numerics"),
+  pkg = character(0L),
+  supported.tasks = "classif",
+  supported.features = "numerics",
   fun = function(task, nselect, ...) {
-    d = getTaskData(task, target.extra = TRUE)
-    y = as.integer(d$target)
-    X = as.matrix(d$data)
-    an = Rfast::anovas(X, y)
-    for (i in which(is.na(an[, "F value"]))) {
-      j = !is.na(X[,i])
-      if (any(j)) {
-        an[i, ] = Rfast::anovas(X[j, i, drop = FALSE], y[j])
-      }
-    }
-    setNames(an[, "F value"], getTaskFeatureNames(task))
+    data = getTaskData(task)
+    vnapply(getTaskFeatureNames(task), function(feat.name) {
+      f = as.formula(stri_paste(feat.name, "~", getTaskTargetNames(task)))
+      aov.t = aov(f, data = data)
+      summary(aov.t)[[1L]][1L, "F value"]
+    })
   }
 )
 
@@ -547,12 +535,12 @@ makeFilter(
   name = "kruskal.test",
   desc = "Kruskal Test for binary and multiclass classification tasks",
   pkg = character(0L),
-  supported.tasks = c("classif"),
+  supported.tasks = "classif",
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     data = getTaskData(task)
     sapply(getTaskFeatureNames(task), function(feat.name) {
-      f = as.formula(stri_paste(feat.name,"~", getTaskTargetNames(task)))
+      f = as.formula(stri_paste(feat.name, "~", getTaskTargetNames(task)))
       t = kruskal.test(f, data = data)
       unname(t$statistic)
     })
@@ -570,8 +558,8 @@ makeFilter(
   desc = "A simple variance filter",
   pkg = character(0L),
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics"),
-  fun = function(task, nselect, na.rm = FALSE, ...) {
+  supported.features = "numerics",
+  fun = function(task, nselect, na.rm = TRUE, ...) {
     data = getTaskData(task)
     sapply(getTaskFeatureNames(task), function(feat.name) {
       var(data[[feat.name]], na.rm = na.rm)
@@ -581,11 +569,11 @@ makeFilter(
 
 #' Filter \dQuote{permutation.importance} computes a loss function between predictions made by a
 #' learner before and after a feature is permuted. Special arguments to the filter function are
-#' \code{imp.learner}, a [\code{\link{Learner}} or \code{character(1)}] which specifies the learner
-#' to use when computing the permutation importance, \code{contrast}, a \code{function} which takes two
-#' numeric vectors and returns one (default is the difference), \code{aggregation}, a \code{function} which
-#' takes a \code{numeric} and returns a \code{numeric(1)} (default is the mean), \code{nmc},
-#' an \code{integer(1)}, and \code{replace}, a \code{logical(1)} which determines whether the feature being
+#' `imp.learner`, a ([Learner] or `character(1)]) which specifies the learner
+#' to use when computing the permutation importance, `contrast`, a `function` which takes two
+#' numeric vectors and returns one (default is the difference), `aggregation`, a `function` which
+#' takes a `numeric` and returns a `numeric(1)` (default is the mean), `nmc`,
+#' an `integer(1)`, and `replace`, a `logical(1)` which determines whether the feature being
 #' permuted is sampled with or without replacement.
 #'
 #' @rdname makeFilter
@@ -607,3 +595,69 @@ makeFilter(
     return(imp)
   }
 )
+
+#' Filter \dQuote{auc} determines for each feature, how well the target
+#' variable can be predicted only based on this feature. More precisely, the
+#' prediction rule is: class 1 if the feature exceeds a threshold and class 0
+#' otherwise. The performance of this classification rule is measured by the
+#' AUC and the resulting filter score is |0.5 - AUC|.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+makeFilter(
+  name = "auc",
+  desc = "AUC filter for binary classification tasks",
+  pkg  = character(0L),
+  supported.tasks = "classif",
+  supported.features = "numerics",
+  fun = function(task, nselect, ...) {
+    data = getTaskData(task, target.extra = TRUE)
+    score = vnapply(data$data, function(x, y) {
+      measureAUC(x, y, task$task.desc$negative, task$task.desc$positive)
+    }, y = data$target)
+    abs(0.5 - score)
+  }
+)
+
+
+#' Filter \dQuote{ranger.permutation} trains a ranger learner with
+#' \dQuote{importance = "permutation"} and assesses the variable
+#' importance for each feature.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+makeFilter(
+  name = "ranger.permutation",
+  desc = "Variable importance based on ranger permutation importance",
+  pkg  = "ranger",
+  supported.tasks = c("classif", "regr", "surv"),
+  supported.features = c("numerics", "factors", "ordered"),
+  fun = function(task, nselect, ...) {
+    lrn.type = paste0(getTaskType(task), ".ranger")
+    lrn = makeLearner(lrn.type, importance = "permutation", ...)
+    mod = train(lrn, task)
+    ranger::importance(mod$learner.model)
+  }
+)
+
+
+#' Filter \dQuote{ranger.impurity} trains a ranger learner with
+#' \dQuote{importance = "impurity"} and assesses the variable
+#' importance for each feature.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+makeFilter(
+  name = "ranger.impurity",
+  desc = "Variable importance based on ranger impurity importance",
+  pkg  = "ranger",
+  supported.tasks = c("classif", "regr"),
+  supported.features = c("numerics", "factors", "ordered"),
+  fun = function(task, nselect, ...) {
+    lrn.type = paste0(getTaskType(task), ".ranger")
+    lrn = makeLearner(lrn.type, importance = "impurity", ...)
+    mod = train(lrn, task)
+    ranger::importance(mod$learner.model)
+  }
+)
+
