@@ -14,7 +14,8 @@ makeRLearner.classif.LiblineaRL1L2SVC = function() {
     properties = c("twoclass", "multiclass", "numerics", "class.weights"),
     class.weights.param = "wi",
     name = "L1-Regularized L2-Loss Support Vector Classification",
-    short.name = "liblinl1l2svc"
+    short.name = "liblinl1l2svc",
+    callees = "LiblineaR"
   )
 }
 
