@@ -10,12 +10,12 @@ makeRLearner.classif.rda = function() {
       makeIntegerLearnerParam(id = "fold", default = 10L, lower = 1L),
       makeNumericLearnerParam(id = "train.fraction", default = 0.5, lower = 0, upper = 1),
       makeLogicalLearnerParam(id = "output", default = FALSE, tunable = FALSE),
-      makeDiscreteLearnerParam(id = "schedule", default = 1L, values = 1:2, requires = quote(simAnn==FALSE)),
-      makeNumericLearnerParam(id = "T.start", default = 0.1, lower = 0, requires = quote(simAnn==TRUE)),
-      makeNumericLearnerParam(id = "halflife", default = 0.1, lower = 0, requires = quote(simAnn==TRUE || schedule==1)),
-      makeNumericLearnerParam(id = "zero.temp", default = 0.01, lower = 0, requires = quote(simAnn==TRUE || schedule==1)),
-      makeNumericLearnerParam(id = "alpha", default = 2, lower = 1, requires = quote(simAnn==TRUE || schedule==2)),
-      makeIntegerLearnerParam(id = "K", default = 100L, lower = 1L, requires = quote(simAnn==TRUE || schedule==2)),
+      makeDiscreteLearnerParam(id = "schedule", default = 2L, values = 1:2, requires = quote(simAnn == TRUE)),
+      makeNumericLearnerParam(id = "T.start", default = 0.1, lower = 0, requires = quote(simAnn == TRUE)),
+      makeNumericLearnerParam(id = "halflife", default = 50, lower = 0, requires = quote(simAnn == TRUE && schedule == 1)),
+      makeNumericLearnerParam(id = "zero.temp", default = 0.01, lower = 0, requires = quote(simAnn == TRUE && schedule == 1)),
+      makeNumericLearnerParam(id = "alpha", default = 2, lower = 1, requires = quote(simAnn == TRUE && schedule == 2)),
+      makeIntegerLearnerParam(id = "K", default = 100L, lower = 1L, requires = quote(simAnn == TRUE && schedule == 2)),
       makeLogicalLearnerParam(id = "trafo", default = TRUE),
       makeLogicalLearnerParam(id = "simAnn", default = FALSE),
       makeLogicalLearnerParam(id = "estimate.error", default = TRUE)
@@ -24,7 +24,8 @@ makeRLearner.classif.rda = function() {
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Regularized Discriminant Analysis",
     short.name = "rda",
-    note = "`estimate.error` has been set to `FALSE` by default for speed."
+    note = "`estimate.error` has been set to `FALSE` by default for speed.",
+    callees = "rda"
   )
 }
 
