@@ -9,7 +9,8 @@ makeRLearner.regr.lm = function() {
     ),
     properties = c("numerics", "factors", "se", "weights"),
     name = "Simple Linear Regression",
-    short.name = "lm"
+    short.name = "lm",
+    callees = c("lm", "lm.fit", "lm.wfit")
   )
 }
 
