@@ -30,7 +30,7 @@ makeRLearner.surv.glmnet = function() {
       makeNumericLearnerParam(id = "prec", default = 1e-10),
       makeIntegerLearnerParam(id = "mxit", default = 100, lower = 1)
     ),
-    properties = c("numerics", "factors", "ordered", "weights", "rcens"),
+    properties = c("numerics", "factors", "ordered", "weights"),
     par.vals = list(s = 0.01),
     name = "GLM with Regularization",
     short.name = "glmnet",
@@ -40,13 +40,14 @@ makeRLearner.surv.glmnet = function() {
       glmnet uses a global control object for its parameters. mlr resets all control parameters to their defaults
       before setting the specified parameters and after training.
       If you are setting glmnet.control parameters through glmnet.control,
-      you need to save and re-set them after running the glmnet learner."
+      you need to save and re-set them after running the glmnet learner.",
+    callees = c("glmnet", "glmnet.control", "predict.glmnet")
   )
 }
 
 #' @export
 trainLearner.surv.glmnet = function(.learner, .task, .subset, .weights = NULL,  ...) {
-  d = getTaskData(.task, subset = .subset, target.extra = TRUE, recode.target = "rcens")
+  d = getTaskData(.task, subset = .subset, target.extra = TRUE, recode.target = "surv")
   info = getFixDataInfo(d$data, factors.to.dummies = TRUE, ordered.to.int = TRUE)
   args = c(list(x = as.matrix(fixDataForLearner(d$data, info)), y = d$target, family = "cox"), list(...))
   rm(d)
