@@ -3,32 +3,32 @@
 #' @description
 #' Creates a learner object, which can be
 #' used like any other learner object.
-#' Internally uses \code{\link{smote}} before every model fit.
+#' Internally uses [smote] before every model fit.
 #'
 #' Note that observation weights do not influence the sampling and are simply passed
 #' down to the next learner.
 #'
 #' @template arg_learner
-#' @param sw.rate [\code{numeric(1)}]\cr
-#'   Factor to oversample the smaller class. Must be between 1 and \code{Inf},
+#' @param sw.rate (`numeric(1)`)\cr
+#'   Factor to oversample the smaller class. Must be between 1 and `Inf`,
 #'   where 1 means no oversampling and 2 would mean doubling the class size.
 #'   Default is 1.
-#' @param sw.nn [\code{integer(1)}]\cr
+#' @param sw.nn (`integer(1)`)\cr
 #'   Number of nearest neighbors to consider.
 #'   Default is 5.
-#' @param sw.standardize [\code{logical(1)}]\cr
+#' @param sw.standardize (`logical(1)`)\cr
 #'   Standardize input variables before calculating the nearest neighbors
 #'   for data sets with numeric input variables only. For mixed variables
 #'   (numeric and factor) the gower distance is used and variables are
 #'   standardized anyway.
-#'   Default is \code{TRUE}.
-#' @param sw.alt.logic [\code{logical(1)}]\cr
+#'   Default is `TRUE`.
+#' @param sw.alt.logic (`logical(1)`)\cr
 #'   Use an alternative logic for selection of minority class observations.
 #'   Instead of sampling a minority class element AND one of its nearest
 #'   neighbors, each minority class element is taken multiple times (depending
 #'   on rate) for the interpolation and only the corresponding nearest neighbor
 #'   is sampled.
-#'   Default is \code{FALSE}.
+#'   Default is `FALSE`.
 #' @template ret_learner
 #' @family wrapper
 #' @export
@@ -63,7 +63,7 @@ makeSMOTEWrapper = function(learner, sw.rate = 1, sw.nn = 5L,
 }
 
 #' @export
-trainLearner.SMOTEWrapper = function(.learner, .task, .subset, .weights = NULL, sw.rate = 1,
+trainLearner.SMOTEWrapper = function(.learner, .task, .subset = NULL, .weights = NULL, sw.rate = 1,
   sw.nn = 5, sw.standardize = TRUE, sw.alt.logic = FALSE, ...) {
 
   .task = subsetTask(.task, .subset)
