@@ -6,71 +6,78 @@
 #' the type of the task.
 #' It also contains a description object detailing further aspects of the data.
 #'
-#' Useful operators are: \code{\link{getTaskFormula}},
-#' \code{\link{getTaskFeatureNames}},
-#' \code{\link{getTaskData}},
-#' \code{\link{getTaskTargets}}, and
-#' \code{\link{subsetTask}}.
+#' Useful operators are: [getTaskFormula],
+#' [getTaskFeatureNames],
+#' [getTaskData],
+#' [getTaskTargets], and
+#' [subsetTask].
 #'
 #' Object members:
 #' \describe{
-#' \item{env [\code{environment}]}{Environment where data for the task are stored.
-#'   Use \code{\link{getTaskData}} in order to access it.}
-#' \item{weights [\code{numeric}]}{See argument. \code{NULL} if not present.}
-#' \item{blocking [\code{factor}]}{See argument. \code{NULL} if not present.}
-#' \item{task.desc [\code{\link{TaskDesc}}]}{Encapsulates further information about the task.}
+#' \item{env (`environment`)}{Environment where data for the task are stored.
+#'   Use [getTaskData] in order to access it.}
+#' \item{weights ([numeric])}{See argument. `NULL` if not present.}
+#' \item{blocking ([factor])}{See argument. `NULL` if not present.}
+#' \item{task.desc ([TaskDesc])}{Encapsulates further information about the task.}
 #' }
 #'
-#' Notes:
+#' @details
 #' For multilabel classification we assume that the presence of labels is encoded via logical
-#' columns in \code{data}. The name of the column specifies the name of the label. \code{target}
+#' columns in `data`. The name of the column specifies the name of the label. `target`
 #' is then a char vector that points to these columns.
 #'
-#' @param id [\code{character(1)}]\cr
+#' Functional data can be added to a task via matrix columns. For more information refer to
+#' [makeFunctionalData].
+#'
+#' @param id (`character(1)`)\cr
 #'   Id string for object.
-#'   Default is the name of the R variable passed to \code{data}.
-#' @param data [\code{data.frame}]\cr
+#'   Default is the name of the R variable passed to `data`.
+#' @param data ([data.frame])\cr
 #'   A data frame containing the features and target variable(s).
-#' @param target [\code{character(1)} | \code{character(2)} | \code{character(n.classes)}]\cr
+#' @param target (`character(1)` | `character(2)` | `character(n.classes)`)\cr
 #'   Name(s) of the target variable(s).
 #'   For survival analysis these are the names of the survival time and event columns,
 #'   so it has length 2. For multilabel classification it contains the names of the logical
 #'   columns that encode whether a label is present or not and its length corresponds to the
 #'   number of classes.
-#' @param costs [\code{data.frame}]\cr
+#' @param costs ([data.frame])\cr
 #'   A numeric matrix or data frame containing the costs of misclassification.
 #'   We assume the general case of observation specific costs.
-#'   This means we have n rows, corresponding to the observations, in the same order as \code{data}.
+#'   This means we have n rows, corresponding to the observations, in the same order as `data`.
 #'   The columns correspond to classes and their names are the class labels
 #'   (if unnamed we use y1 to yk as labels).
 #'   Each entry (i,j) of the matrix specifies the cost of predicting class j
 #'   for observation i.
-#' @param weights [\code{numeric}]\cr
+#' @param weights ([numeric])\cr
 #'   Optional, non-negative case weight vector to be used during fitting.
 #'   Cannot be set for cost-sensitive learning.
-#'   Default is \code{NULL} which means no (= equal) weights.
-#' @param blocking [\code{factor}]\cr
+#'   Default is `NULL` which means no (= equal) weights.
+#' @param blocking ([factor])\cr
 #'   An optional factor of the same length as the number of observations.
 #'   Observations with the same blocking level \dQuote{belong together}.
 #'   Specifically, they are either put all in the training or the test set
 #'   during a resampling iteration.
-#'   Default is \code{NULL} which means no blocking.
-#' @param positive [\code{character(1)}]\cr
+#'   Default is `NULL` which means no blocking.
+#' @param positive (`character(1)`)\cr
 #'   Positive class for binary classification (otherwise ignored and set to NA).
 #'   Default is the first factor level of the target attribute.
-#' @param fixup.data [\code{character(1)}]\cr
+#' @param fixup.data (`character(1)`)\cr
 #'   Should some basic cleaning up of data be performed?
 #'   Currently this means removing empty factor levels for the columns.
-#'   Possible coices are:
+#'   Possible choices are:
 #'   \dQuote{no} = Don't do it.
 #'   \dQuote{warn} = Do it but warn about it.
 #'   \dQuote{quiet} = Do it but keep silent.
 #'   Default is \dQuote{warn}.
-#' @param check.data [\code{logical(1)}]\cr
+#' @param check.data (`logical(1)`)\cr
 #'   Should sanity of data be checked initially at task creation?
 #'   You should have good reasons to turn this off (one might be speed).
-#'   Default is \code{TRUE}.
-#' @return [\code{\link{Task}}].
+#'   Default is `TRUE`.
+#' @param coordinates ([data.frame])\cr
+#'   Coordinates of a spatial data set that will be used for spatial partitioning of the data in a spatial cross-validation resampling setting.
+#'   Coordinates have to be numeric values.
+#'   Provided [data.frame] needs to have the same number of rows as data and consist of at least two dimensions.
+#' @return ([Task]).
 #' @name Task
 #' @rdname Task
 #' @aliases ClassifTask RegrTask SurvTask CostSensTask ClusterTask MultilabelTask
@@ -90,7 +97,26 @@
 #' }
 NULL
 
-makeTask = function(type, data, weights = NULL, blocking = NULL, fixup.data = "warn", check.data = TRUE) {
+#' Exported for internal use.
+#' @param id (`character(1)`)\cr
+#'   task id
+#' @param data ([data.frame])\cr
+#'   data
+#' @param target ([character])\cr
+#'   target columns
+#' @param weights ([numeric])\cr
+#'   weights
+#' @param blocking ([numeric`\cr
+#'   task data blocking
+#' @param coordinates ([data.frame])\cr
+#'   Coordinates of a spatial data set that will be used for spatial partitioning of the data in a spatial cross-validation resampling setting.
+#'   Coordinates have to be numeric values.
+#'   Provided ([data.frame]) needs to have the same number of rows as data and consist of at least two dimensions.
+#' @keywords internal
+#' @name makeTaskDesc
+NULL
+
+makeTask = function(type, data, weights = NULL, blocking = NULL, fixup.data = "warn", check.data = TRUE, coordinates = NULL) {
   if (fixup.data != "no") {
     if (fixup.data == "quiet") {
       data = droplevels(data)
@@ -122,6 +148,17 @@ makeTask = function(type, data, weights = NULL, blocking = NULL, fixup.data = "w
       if (length(blocking) && length(blocking) != nrow(data))
         stop("Blocking has to be of the same length as number of rows in data! Or pass none at all.")
     }
+    if (!is.null(coordinates)) {
+      if (nrow(coordinates) != nrow(data)) {
+        stop("Coordinates need to have the same length data! Or pass none at all.")
+      }
+      if (ncol(coordinates) < 2) {
+        stop("Supplied coordinates need to consist of at least two dimensions.")
+      }
+      if (!is.data.frame(coordinates)) {
+        warningf("Provided coordinates are not given as a data frame but as class %s. Please provide a data frame.", class(coordinates))
+      }
+    }
   }
 
   env = new.env(parent = emptyenv())
@@ -131,6 +168,7 @@ makeTask = function(type, data, weights = NULL, blocking = NULL, fixup.data = "w
     env = env,
     weights = weights,
     blocking = blocking,
+    coordinates = coordinates,
     task.desc = NA
   )
 }
@@ -166,4 +204,5 @@ print.Task = function(x, print.weights = TRUE, ...) {
   if (print.weights)
     catf("Has weights: %s", td$has.weights)
   catf("Has blocking: %s", td$has.blocking)
+  catf("Has coordinates: %s", td$has.coordinates)
 }
