@@ -7,24 +7,26 @@
 #'
 #' Object members:
 #' \describe{
-#' \item{learner [\code{\link{Learner}}]}{Learner that was optimized.}
-#' \item{control [\code{\link{TuneControl}}]}{Control object from tuning.}
-#' \item{x [\code{list}]}{List of lists of non-dominated hyperparameter settings in pareto set.
-#'   Note that when you have trafos on some of your params, \code{x} will always be
+#' \item{learner ([Learner])}{Learner that was optimized.}
+#' \item{control ([TuneControl])}{Control object from tuning.}
+#' \item{x ([list])}{List of lists of non-dominated hyperparameter settings in pareto set.
+#'   Note that when you have trafos on some of your params, `x` will always be
 #'   on the TRANSFORMED scale so you directly use it.}
-#' \item{y [\code{matrix}]}{Pareto front for \code{x}.}
-#' \item{opt.path [\code{\link[ParamHelpers]{OptPath}}]}{Optimization path which lead to \code{x}.
+#' \item{y ([matrix])}{Pareto front for `x`.}
+#' \item{threshold}{Currently `NULL`.}
+#' \item{opt.path ([ParamHelpers::OptPath])}{Optimization path which lead to `x`.
 #'   Note that when you have trafos on some of your params, the opt.path always contains the
-#'   UNTRANSFORMED values on the original scale. You can simply call \code{trafoOptPath(opt.path)} to
+#'   UNTRANSFORMED values on the original scale. You can simply call `trafoOptPath(opt.path)` to
 #'   transform them, or, \code{as.data.frame{trafoOptPath(opt.path)}}}
-#' \item{measures [(list of) \code{\link{Measure}}]}{Performance measures.}
+#' \item{ind (`integer(n)`)}{Indices of Pareto optimal params in `opt.path`.}
+#' \item{measures [(list of) [Measure])}{Performance measures.}
 #' }
 #' @name TuneMultiCritResult
 #' @rdname TuneMultiCritResult
 NULL
-makeTuneMultiCritResult = function(learner, ind, x, y, control, opt.path, measures) {
+makeTuneMultiCritResult = function(learner, ind, x, y, control, opt.path, measures, ...) {
   # set threshold to NULL, we can not currently tune for it in an MCO way
-  or = makeOptResult(learner, control, x, y, NULL, opt.path, "TuneMultiCritResult")
+  or = makeOptResult(learner, control, x, y, NULL, opt.path, "TuneMultiCritResult", ...)
   or$ind = ind
   or$measures = measures
   return(or)
