@@ -3,15 +3,15 @@
 #' @description
 #' Fuses a base learner with a search strategy to select its hyperparameters.
 #' Creates a learner object, which can be used like any other learner object,
-#' but which internally uses \code{\link{tuneParams}}.
+#' but which internally uses [tuneParams].
 #' If the train function is called on it,
 #' the search strategy and resampling are invoked
 #' to select an optimal set of hyperparameter values. Finally, a model is fitted on the
 #' complete training data with these optimal hyperparameters and returned.
-#' See \code{\link{tuneParams}} for more details.
+#' See [tuneParams] for more details.
 #'
 #' After training, the optimal hyperparameters (and other related information) can be retrieved with
-#' \code{\link{getTuneResult}}.
+#' [getTuneResult].
 #'
 #' @template arg_learner
 #' @inheritParams tuneParams
@@ -56,7 +56,7 @@ makeTuneWrapper = function(learner, resampling, measures, par.set, control, show
 }
 
 #' @export
-trainLearner.TuneWrapper = function(.learner, .task, .subset,  ...) {
+trainLearner.TuneWrapper = function(.learner, .task, .subset = NULL,  ...) {
   .task = subsetTask(.task, .subset)
   or = tuneParams(.learner$next.learner, .task, .learner$resampling, .learner$measures,
                   .learner$opt.pars, .learner$control, .learner$show.info)
@@ -79,7 +79,7 @@ predictLearner.TuneWrapper = function(.learner, .model, .newdata, ...) {
 }
 
 #' @export
-makeWrappedModel.TuneWrapper = function(learner, learner.model, task.desc, subset, features, factor.levels, time) {
+makeWrappedModel.TuneWrapper = function(learner, learner.model, task.desc, subset = NULL, features, factor.levels, time) {
   # set threshold in learner so it is used in predict calls from here on
   if (learner$control$tune.threshold)
     learner = setPredictThreshold(learner, learner.model$opt.result$threshold)
