@@ -1,11 +1,11 @@
 #' Convert arguments to control structure.
 #'
-#' Find all elements in \code{...} which are not missing and
-#' call \code{control} on them.
+#' Find all elements in `...` which are not missing and
+#' call `control` on them.
 #'
-#' @param control [\code{function}]\cr
+#' @param control (`function`)\cr
 #'   Function that creates control structure.
-#' @param ... [any]\cr
+#' @param ... (any)\cr
 #'   Arguments for control structure function.
 #' @return Control structure for learner.
 #' @export
@@ -14,7 +14,7 @@ learnerArgsToControl = function(control, ...) {
   dots = match.call(expand.dots = FALSE)$...
   for (i in seq_along(dots)) {
     arg = dots[[i]]
-    is_missing = if (is.symbol(arg)) {
+    is.missing = if (is.symbol(arg)) {
       argname = as.character(arg)
       eval(substitute(missing(symbol), list(symbol = arg)),
            envir = parent.frame())
@@ -22,7 +22,7 @@ learnerArgsToControl = function(control, ...) {
       argname = names(dots)[i]
       FALSE
     }
-    if (!is_missing) {
+    if (!is.missing) {
       value = tryCatch(eval(arg, envir = parent.frame()),
                        error = function(...) NULL)
       if (!is.null(value)) {
