@@ -6,26 +6,29 @@
 #' of the prediction (or maybe only the model, think AIC).
 #' The measure itself knows whether it wants to be minimized or maximized and for what tasks it is applicable.
 #'
-#' All supported measures can be found by \code{\link{listMeasures}} or as a table
-#' in the tutorial appendix: \url{http://mlr-org.github.io/mlr-tutorial/release/html/measures/}.
+#' All supported measures can be found by [listMeasures] or as a table
+#' in the tutorial appendix: <http://mlr-org.github.io/mlr-tutorial/release/html/measures/>.
 #'
-#' If you want a measure for a misclassification cost matrix, look at \code{\link{makeCostMeasure}}.
-#' If you want to implement your own measure, look at \code{\link{makeMeasure}}.
+#' If you want a measure for a misclassification cost matrix, look at [makeCostMeasure].
+#' If you want to implement your own measure, look at [makeMeasure].
 #'
 #' Most measures can directly be accessed via the function named after the scheme measureX (e.g. measureSSE).
 #'
 #' For clustering measures, we compact the predicted cluster IDs such that they form a continuous series
 #' starting with 1. If this is not the case, some of the measures will generate warnings.
 #'
-#' @param truth [\code{factor}]\cr
+#' Some measure have parameters. Their defaults are set in the constructor [makeMeasure] and can be
+#' overwritten using [setMeasurePars].
+#'
+#' @param truth ([factor])\cr
 #'   Vector of the true class.
-#' @param response [\code{factor}]\cr
+#' @param response ([factor])\cr
 #'   Vector of the predicted class.
-#' @param negative [\code{character(1)}]\cr
+#' @param negative (`character(1)`)\cr
 #'   The name of the negative class.
-#' @param positive [\code{character(1)}]\cr
+#' @param positive (`character(1)`)\cr
 #'   The name of the positive class.
-#' @param probabilities [\code{numeric} | \code{matrix}]\cr
+#' @param probabilities ([numeric] | [matrix])\cr
 #'   a) For purely binary classification measures: The predicted probabilities for the positive class as a numeric vector.
 #'   b) For multiclass classification measures: The predicted probabilities for all classes, always as a numeric matrix, where
 #'   columns are named with class labels.
@@ -274,7 +277,7 @@ measureEXPVAR = function(truth, response) {
 #' @export arsq
 #' @rdname measures
 #' @format none
-arsq = makeMeasure(id = "adjrsq", minimize = FALSE, best = 1, worst = 0,
+arsq = makeMeasure(id = "arsq", minimize = FALSE, best = 1, worst = 0,
   properties = c("regr", "req.pred", "req.truth"),
   name = "Adjusted coefficient of determination",
   note = "Defined as: 1 - (1 - rsq) * (p / (n - p - 1L)). Adjusted R-squared is only defined for normal linear regression.",
@@ -305,12 +308,12 @@ rrse = makeMeasure(id = "rrse", minimize = TRUE, best = 0, worst = Inf,
 #' @rdname measures
 #' @format none
 measureRRSE = function(truth, response){
-  tss = sum((truth-mean(truth))^2L)
+  tss = sum((truth - mean(truth))^2L)
   if (tss == 0){
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
-  sqrt(measureSSE(truth, response)/tss)
+  sqrt(measureSSE(truth, response) / tss)
 }
 
 #' @export rae
@@ -329,12 +332,12 @@ rae = makeMeasure(id = "rae", minimize = TRUE, best = 0, worst = Inf,
 #' @rdname measures
 #' @format none
 measureRAE = function(truth, response){
-  meanad = sum(abs(truth-mean(truth)))
+  meanad = sum(abs(truth - mean(truth)))
   if (meanad == 0){
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
-  return(measureSAE(truth, response)/meanad)
+  return(measureSAE(truth, response) / meanad)
 }
 
 #' @export mape
@@ -357,7 +360,7 @@ measureMAPE = function(truth, response){
     warning("Measure is undefined if any truth value is equal to 0.")
     return(NA_real_)
   }
-  return(mean(abs((truth-response)/truth)))
+  return(mean(abs((truth - response) / truth)))
 }
 
 #' @export msle
@@ -393,14 +396,21 @@ rmsle = makeMeasure(id = "rmsle", minimize = TRUE, best = 0, worst = Inf,
   properties = c("regr", "req.pred", "req.truth"),
   name = "Root mean squared logarithmic error",
   note = "Defined as: sqrt(msle). Definition taken from:
-  Definition taken from: https://www.kaggle.com/wiki/RootMeanSquaredLogarithmicError.
+  Definition taken from: https: / /www.kaggle.com / wiki / RootMeanSquaredLogarithmicError.
   This measure is mostly used for count data, note that all predicted and actual target values
   must be greater or equal '-1' to compute the measure.",
   fun = function(task, model, pred, feats, extra.args) {
-    sqrt(measureMSLE(pred$data$truth, pred$data$response))
+    measureRMSLE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureRMSLE
+#' @rdname measures
+#' @format none
+measureRMSLE = function(truth, response) {
+  sqrt(measureMSLE(truth, response))
+}
+
 #' @export kendalltau
 #' @rdname measures
 #' @format none
@@ -490,14 +500,20 @@ ber = makeMeasure(id = "ber", minimize = TRUE, best = 0, worst = 1,
   name = "Balanced error rate",
   note = "Mean of misclassification error rates on all individual classes.",
   fun = function(task, model, pred, feats, extra.args) {
-    # special case for predictions from FailureModel
-    if (anyMissing(pred$data$response))
-      return(NA_real_)
-    n = length(pred$task.desc$class.levels) + 1L
-    mean(calculateConfusionMatrix(pred, relative = TRUE)$relative.row[-n, n])
+    measureBER(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureBER
+#' @rdname measures
+#' @format none
+measureBER = function(truth, response) {
+  # special case for predictions from FailureModel
+  if (anyMissing(response))
+    return(NA_real_)
+  mean(diag(1 - (table(truth, response) / table(truth, truth))))
+}
+
 #' @export multiclass.aunu
 #' @rdname measures
 #' @format none
@@ -514,9 +530,9 @@ multiclass.aunu = makeMeasure(id = "multiclass.aunu", minimize = FALSE, best = 1
 #' @rdname measures
 #' @format none
 measureAUNU = function(probabilities, truth) {
-  if(length(unique(truth)) != nlevels(truth)){
+  if (length(unique(truth)) != nlevels(truth)){
     warning("Measure is undefined if there isn't at least one sample per class.")
-	return(NA_real_)
+    return(NA_real_)
   }
   mean(vnapply(1:nlevels(truth), function(i) colAUC(probabilities[, i], truth == levels(truth)[i])))
 }
@@ -537,11 +553,11 @@ multiclass.aunp = makeMeasure(id = "multiclass.aunp", minimize = FALSE, best = 1
 #' @rdname measures
 #' @format none
 measureAUNP = function(probabilities, truth) {
-  if(length(unique(truth)) != nlevels(truth)){
+  if (length(unique(truth)) != nlevels(truth)){
     warning("Measure is undefined if there isn't at least one sample per class.")
-	return(NA_real_)
+    return(NA_real_)
   }
-  sum(vnapply(1:nlevels(truth), function(i) mean(truth == levels(truth)[i]) * colAUC(probabilities[,i], truth == levels(truth)[i])))
+  sum(vnapply(1:nlevels(truth), function(i) mean(truth == levels(truth)[i]) * colAUC(probabilities[, i], truth == levels(truth)[i])))
 }
 
 #' @export multiclass.au1u
@@ -562,7 +578,7 @@ multiclass.au1u = makeMeasure(id = "multiclass.au1u", minimize = FALSE, best = 1
 measureAU1U = function(probabilities, truth) {
   m = colAUC(probabilities, truth)
   c = c(combn(1:nlevels(truth), 2))
-  mean(m[cbind(rep(1:nrow(m), each = 2), c)])
+  mean(m[cbind(rep(seq_len(nrow(m)), each = 2), c)])
 }
 
 #' @export multiclass.au1p
@@ -585,7 +601,7 @@ measureAU1P = function(probabilities, truth) {
   weights = table(truth) / length(truth)
   m = m * matrix(rep(weights, each = nrow(m)), ncol = length(weights))
   c = c(combn(1:nlevels(truth), 2))
-  sum(m[cbind(rep(1:nrow(m), each = 2), c)]) / (nlevels(truth) - 1)
+  sum(m[cbind(rep(seq_len(nrow(m)), each = 2), c)]) / (nlevels(truth) - 1)
 }
 
 #' @export multiclass.brier
@@ -626,12 +642,12 @@ logloss = makeMeasure(id = "logloss", minimize = TRUE, best = 0, worst = Inf,
 #' @format none
 measureLogloss = function(probabilities, truth){
   eps = 1e-15
-  #let's confine the predicted probabilities to [eps,1-eps], so logLoss doesn't reach infinity under any circumstance
-  probabilities[probabilities > 1-eps] = 1-eps
+  #let's confine the predicted probabilities to [eps,1 - eps], so logLoss doesn't reach infinity under any circumstance
+  probabilities[probabilities > 1 - eps] = 1 - eps
   probabilities[probabilities < eps] = eps
   truth = match(as.character(truth), colnames(probabilities))
   p = getRowEls(probabilities, truth)
-  -1*mean(log(p))
+  -1 * mean(log(p))
 }
 
 #' @export ssr
@@ -641,7 +657,7 @@ ssr = makeMeasure(id = "ssr", minimize = FALSE, best = 1, worst = 0,
   properties = c("classif", "classif.multi", "req.truth", "req.prob"),
   name = "Spherical Scoring Rule",
   note = "Defined as: mean(p_i(sum_j(p_ij))), where p_i is the predicted probability of the true class of observation i and p_ij is the predicted probablity of observation i for class j.
-	See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
+  See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureSSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
   }
@@ -653,7 +669,7 @@ ssr = makeMeasure(id = "ssr", minimize = FALSE, best = 1, worst = 0,
 measureSSR = function(probabilities, truth){
   truth = match(as.character(truth), colnames(probabilities))
   p = getRowEls(probabilities, truth)
-  mean(p/sqrt(rowSums(probabilities^2)))
+  mean(p / sqrt(rowSums(probabilities^2)))
 }
 
 #' @export qsr
@@ -664,7 +680,7 @@ qsr = makeMeasure(id = "qsr", minimize = FALSE, best = 1, worst = -1,
   name = "Quadratic Scoring Rule",
   note = "Defined as: 1 - (1/n) sum_i sum_j (y_ij - p_ij)^2, where y_ij = 1 if observation i has class j (else 0), and p_ij is the predicted probablity of observation i for class j.
   This scoring rule is the same as 1 - multiclass.brier.
-	See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
+  See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureQSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
   }
@@ -675,7 +691,7 @@ qsr = makeMeasure(id = "qsr", minimize = FALSE, best = 1, worst = -1,
 #' @format none
 measureQSR = function(probabilities, truth){
   #We add this line because binary tasks only output one probability column
-  if (is.null(dim(probabilities))) probabilities = cbind(probabilities,1 - probabilities)
+  if (is.null(dim(probabilities))) probabilities = cbind(probabilities, 1 - probabilities)
   truth = factor(truth, levels = colnames(probabilities))
   1 - mean(rowSums((probabilities - createDummyFeatures(truth))^2))
 }
@@ -687,7 +703,7 @@ lsr = makeMeasure(id = "lsr", minimize = FALSE, best = 0, worst = -Inf,
   properties = c("classif", "classif.multi", "req.truth", "req.prob"),
   name = "Logarithmic Scoring Rule",
   note = "Defined as: mean(log(p_i)), where p_i is the predicted probability of the true class of observation i.
-	This scoring rule is the same as the negative logloss, self-information or surprisal.
+  This scoring rule is the same as the negative logloss, self-information or surprisal.
   See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureLSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
@@ -698,7 +714,7 @@ lsr = makeMeasure(id = "lsr", minimize = FALSE, best = 0, worst = -Inf,
 #' @rdname measures
 #' @format none
 measureLSR = function(probabilities, truth){
-  -1*measureLogloss(probabilities, truth)
+  -1 * measureLogloss(probabilities, truth)
 }
 
 #' @export kappa
@@ -789,23 +805,23 @@ auc = makeMeasure(id = "auc", minimize = FALSE, best = 1, worst = 0,
 #' @rdname measures
 #' @format none
 measureAUC = function(probabilities, truth, negative, positive) {
-	if (is.factor(truth)) {
-  	i = as.integer(truth) == which(levels(truth) == positive)
+  if (is.factor(truth)) {
+    i = as.integer(truth) == which(levels(truth) == positive)
   } else {
-	  i = truth == positive
+    i = truth == positive
+  }
+  if (length(unique(i)) < 2L) {
+    stop("truth vector must have at least two classes")
   }
-	if (length(unique(i)) < 2L) {
-		stop("truth vector must have at least two classes")
-	}
   #Use fast ranking function from data.table for larger vectors
   if (length(i) > 5000L) {
-  	r = frankv(probabilities)
+    r = frankv(probabilities)
   } else {
-  	r = rank(probabilities)
+    r = rank(probabilities)
   }
-  n_pos = as.numeric(sum(i))
-  n_neg = length(i) - n_pos
-  (sum(r[i]) - n_pos * (n_pos + 1)/2)/(n_pos * n_neg)
+  n.pos = as.numeric(sum(i))
+  n.neg = length(i) - n.pos
+  (sum(r[i]) - n.pos * (n.pos + 1) / 2) / (n.pos * n.neg)
 }
 
 #' @export brier
@@ -857,23 +873,19 @@ measureBrierScaled = function(probabilities, truth, negative, positive) {
 #' @rdname measures
 #' @format none
 bac = makeMeasure(id = "bac", minimize = FALSE, best = 1, worst = 0,
-  properties = c("classif", "req.pred", "req.truth"),
+  properties = c("classif", "classif.multi", "req.pred", "req.truth"),
   name = "Balanced accuracy",
-  note = "Mean of true positive rate and true negative rate.",
+  note = "For binary tasks, mean of true positive rate and true negative rate.",
   fun = function(task, model, pred, feats, extra.args) {
-    mean(c(tp$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$positive),
-      tn$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$negative)))
+    measureBAC(pred$data$truth, pred$data$response)
   }
 )
 
 #' @export measureBAC
 #' @rdname measures
 #' @format none
-measureBAC = function(truth, response, negative, positive) {
-  mean(c(
-    measureTP(truth, response, positive) / sum(truth == positive),
-    measureTN(truth, response, negative) / sum(truth == negative)
-  ))
+measureBAC = function(truth, response) {
+    mean(diag(table(truth, response) / table(truth, truth)))
 }
 
 #' @export tp
@@ -958,7 +970,7 @@ measureFN = function(truth, response, negative) {
 tpr = makeMeasure(id = "tpr", minimize = FALSE, best = 1, worst = 0,
   properties = c("classif", "req.pred", "req.truth"),
   name = "True positive rate",
-  note = "Percentage of correctly classified observations in the positive class. Also called hit rate or recall.",
+  note = "Percentage of correctly classified observations in the positive class. Also called hit rate or recall or sensitivity.",
   fun = function(task, model, pred, feats, extra.args) {
     measureTPR(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
@@ -994,7 +1006,7 @@ measureTNR = function(truth, response, negative) {
 #' @rdname measures
 #' @format none
 fpr = makeMeasure(id = "fpr", minimize = TRUE, best = 0, worst = 1,
-  properties = c("classif" , "req.pred", "req.truth"),
+  properties = c("classif", "req.pred", "req.truth"),
   name = "False positive rate",
   note = "Percentage of misclassified observations in the positive class. Also called false alarm rate or fall-out.",
   fun = function(task, model, pred, feats, extra.args) {
@@ -1034,9 +1046,9 @@ measureFNR = function(truth, response, negative, positive) {
 ppv = makeMeasure(id = "ppv", minimize = FALSE, best = 1, worst = 0,
   properties = c("classif", "req.pred", "req.truth"),
   name = "Positive predictive value",
-  note = "Defined as: tp / (tp + number of fp). Also called precision. If the denominator is 0, PPV is set to be either 1 or 0 depending on whether the highest probability prediction is positive (1) or negative (0).",
+  note = "Defined as: tp / (tp + fp). Also called precision. If the denominator is 0, PPV is set to be either 1 or 0 depending on whether the highest probability prediction is positive (1) or negative (0).",
   fun = function(task, model, pred, feats, extra.args) {
-    if(pred$predict.type == "prob") {
+    if (pred$predict.type == "prob") {
       prob = getPredictionProbabilities(pred)
     } else {
       prob = NULL
@@ -1070,7 +1082,7 @@ measureEdgeCase = function(truth, positive, prob) {
 npv = makeMeasure(id = "npv", minimize = FALSE, best = 1, worst = 0,
   properties = c("classif", "req.pred", "req.truth"),
   name = "Negative predictive value",
-  note = "Defined as: (tn) / (tn + fn).",
+  note = "Defined as: tn / (tn + fn).",
   fun = function(task, model, pred, feats, extra.args) {
     measureNPV(pred$data$truth, pred$data$response, pred$task.desc$negative)
   }
@@ -1089,7 +1101,7 @@ measureNPV = function(truth, response, negative) {
 fdr = makeMeasure(id = "fdr", minimize = TRUE, best = 0, worst = 1,
   properties = c("classif", "req.pred", "req.truth"),
   name = "False discovery rate",
-  note = "Defined as: (fp) / (tn + fn).",
+  note = "Defined as: fp / (tp + fp).",
   fun = function(task, model, pred, feats, extra.args) {
     measureFDR(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
@@ -1108,7 +1120,7 @@ measureFDR = function(truth, response, positive) {
 mcc = makeMeasure(id = "mcc", minimize = FALSE,
   properties = c("classif", "req.pred", "req.truth"), best = 1, worst = -1,
   name = "Matthews correlation coefficient",
-  note = "Defined as sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn))",
+  note = "Defined as (tp * tn - fp * fn) / sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn)), denominator set to 1 if 0",
   fun = function(task, model, pred, feats, extra.args) {
     measureMCC(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
   }
@@ -1122,8 +1134,12 @@ measureMCC = function(truth, response, negative, positive) {
   tp = as.numeric(measureTP(truth, response, positive))
   fn = as.numeric(measureFN(truth, response, negative))
   fp = as.numeric(measureFP(truth, response, positive))
-  (tp * tn - fp * fn) /
-    sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn))
+
+  denom = sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn))
+  # According to Wikipedia, the denominator can be set arbitrarily if it's 0. 1 seems to make as much sense as anything else.
+  if (denom == 0) denom = 1
+
+  (tp * tn - fp * fn) / denom
 }
 
 #' @export f1
@@ -1138,6 +1154,9 @@ f1 = makeMeasure(id = "f1", minimize = FALSE, best = 1, worst = 0,
   }
 )
 
+#' @export measureF1
+#' @rdname measures
+#' @format none
 measureF1 = function(truth, response, positive) {
   2 * measureTP(truth, response, positive) /
     (sum(truth == positive) + sum(response == positive))
@@ -1160,7 +1179,7 @@ gmean = makeMeasure(id = "gmean", minimize = FALSE, best = 1, worst = 0,
 #' @format none
 #' @references
 #' He, H. & Garcia, E. A. (2009)
-#' \emph{Learning from Imbalanced Data.}
+#' *Learning from Imbalanced Data.*
 #' IEEE Transactions on Knowledge and Data Engineering, vol. 21, no. 9. pp. 1263-1284.
 measureGMEAN = function(truth, response, negative, positive) {
   sqrt(measureTPR(truth, response, positive) * measureTNR(truth, response, negative))
@@ -1236,21 +1255,21 @@ multilabel.f1 = makeMeasure(id = "multilabel.f1", minimize = FALSE, best = 1, wo
   properties = c("multilabel", "req.pred", "req.truth"),
   name = "F1 measure (multilabel)",
   note = "Harmonic mean of precision and recall on a per instance basis (Micro-F1), following the
-  definition by Montanes et al.: http://www.sciencedirect.com/science/article/pii/S0031320313004019.
+  definition by Montanes et al.: http: / /www.sciencedirect.com / science / article / pii / S0031320313004019.
   Fractions where the denominator becomes 0 are replaced with 1 before computing the average across all instances.",
   fun = function(task, model, pred, feats, extra.args) {
-    measureMultiLabelF1(getPredictionTruth.PredictionMultilabel(pred),
+    measureMultilabelF1(getPredictionTruth.PredictionMultilabel(pred),
     getPredictionResponse.PredictionMultilabel(pred))
   }
 )
 
-#' @export measureMultiLabelF1
+#' @export measureMultilabelF1
 #' @rdname measures
 #' @format none
-measureMultiLabelF1 = function(truth, response) {
-  numerator = 2*rowSums(truth & response)
+measureMultilabelF1 = function(truth, response) {
+  numerator = 2 * rowSums(truth & response)
   denominator = rowSums(truth + response)
-  mean(ifelse(denominator == 0, 1, numerator/denominator))
+  mean(ifelse(denominator == 0, 1, numerator / denominator))
 }
 
 #' @export multilabel.acc
@@ -1260,7 +1279,7 @@ multilabel.acc = makeMeasure(id = "multilabel.acc", minimize = FALSE, best = 1,
   properties = c("multilabel", "req.pred", "req.truth"),
   name = "Accuracy (multilabel)",
   note = "Averaged proportion of correctly predicted labels with respect to the total number of labels for each instance,
-  following the definition by Charte and Charte: https://journal.r-project.org/archive/2015-2/charte-charte.pdf.
+  following the definition by Charte and Charte: https: / /journal.r-project.org / archive / 2015 - 2 / charte-charte.pdf.
   Fractions where the denominator becomes 0 are replaced with 1 before computing the average across all instances.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelACC(getPredictionTruth.PredictionMultilabel(pred),
@@ -1274,7 +1293,7 @@ multilabel.acc = makeMeasure(id = "multilabel.acc", minimize = FALSE, best = 1,
 measureMultilabelACC = function(truth, response) {
   numerator = rowSums(truth & response)
   denominator = rowSums(truth | response)
-  mean(ifelse(denominator == 0, 1, numerator/denominator))
+  mean(ifelse(denominator == 0, 1, numerator / denominator))
 }
 
 #' @export multilabel.ppv
@@ -1284,7 +1303,7 @@ multilabel.ppv = makeMeasure(id = "multilabel.ppv", minimize = FALSE, best = 1,
   properties = c("multilabel", "req.pred", "req.truth"),
   name = "Positive predictive value (multilabel)",
   note = "Also called precision. Averaged ratio of correctly predicted labels for each instance,
-  following the definition by Charte and Charte: https://journal.r-project.org/archive/2015-2/charte-charte.pdf.
+  following the definition by Charte and Charte: https: / /journal.r-project.org / archive / 2015 - 2 / charte-charte.pdf.
   Fractions where the denominator becomes 0 are ignored in the average calculation.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelPPV(getPredictionTruth.PredictionMultilabel(pred),
@@ -1298,7 +1317,7 @@ multilabel.ppv = makeMeasure(id = "multilabel.ppv", minimize = FALSE, best = 1,
 measureMultilabelPPV = function(truth, response) {
   numerator = rowSums(truth & response)
   denominator = rowSums(response)
-  mean(numerator/denominator, na.rm = TRUE)
+  mean(numerator / denominator, na.rm = TRUE)
 }
 
 #' @export multilabel.tpr
@@ -1308,7 +1327,7 @@ multilabel.tpr = makeMeasure(id = "multilabel.tpr", minimize = FALSE, best = 1,
   properties = c("multilabel", "req.pred", "req.truth"),
   name = "TPR (multilabel)",
   note = "Also called recall. Averaged proportion of predicted labels which are relevant for each instance,
-  following the definition by Charte and Charte: https://journal.r-project.org/archive/2015-2/charte-charte.pdf.
+  following the definition by Charte and Charte: https: / /journal.r-project.org / archive / 2015 - 2 / charte-charte.pdf.
   Fractions where the denominator becomes 0 are ignored in the average calculation.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelTPR(getPredictionTruth.PredictionMultilabel(pred),
@@ -1322,7 +1341,7 @@ multilabel.tpr = makeMeasure(id = "multilabel.tpr", minimize = FALSE, best = 1,
 measureMultilabelTPR = function(truth, response) {
   numerator = rowSums(truth & response)
   denominator = rowSums(truth)
-  mean(numerator/denominator, na.rm = TRUE)
+  mean(numerator / denominator, na.rm = TRUE)
 }
 
 ###############################################################################
@@ -1333,19 +1352,92 @@ measureMultilabelTPR = function(truth, response) {
 #' @format none
 cindex = makeMeasure(id = "cindex", minimize = FALSE, best = 1, worst = 0,
   properties = c("surv", "req.pred", "req.truth"),
-  name = "Concordance index",
+  name = "Harrell's Concordance index",
   note = "Fraction of all pairs of subjects whose predicted survival times are correctly ordered among all subjects that can actually be ordered. In other words, it is the probability of concordance between the predicted and the observed survival.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("Hmisc", default.method = "load")
-    resp = pred$data$response
-    if (anyMissing(resp))
+    requirePackages("_Hmisc")
+    y = getPredictionResponse(pred)
+    if (anyMissing(y))
       return(NA_real_)
-    # FIXME: we need to convert to he correct survival type
-    s = Surv(pred$data$truth.time, pred$data$truth.event)
-    Hmisc::rcorr.cens(-1 * resp, s)[["C Index"]]
+    s = getPredictionTruth(pred)
+    Hmisc::rcorr.cens(-1 * y, s)[["C Index"]]
   }
 )
 
+#' @export cindex.uno
+#' @rdname measures
+#' @format none
+#' @references
+#' H. Uno et al.
+#' *On the C-statistics for Evaluating Overall Adequacy of Risk Prediction Procedures with Censored Survival Data*
+#' Statistics in medicine. 2011;30(10):1105-1117. <http://dx.doi.org/10.1002/sim.4154>.
+cindex.uno = makeMeasure(id = "cindex.uno", minimize = FALSE, best = 1, worst = 0,
+  properties = c("surv", "req.pred", "req.truth", "req.model", "req.task"),
+  name = "Uno's Concordance index",
+  note = "Fraction of all pairs of subjects whose predicted survival times are correctly ordered among all subjects that can actually be ordered. In other words, it is the probability of concordance between the predicted and the observed survival. Corrected by weighting with IPCW as suggested by Uno. Implemented in survAUC::UnoC.",
+  fun = function(task, model, pred, feats, extra.args) {
+    requirePackages("_survAUC")
+    y = getPredictionResponse(pred)
+    if (anyMissing(y))
+      return(NA_real_)
+    surv.train = getTaskTargets(task, recode.target = "surv")[model$subset]
+    max.time = assertNumber(extra.args$max.time, null.ok = TRUE) %??% max(getTaskTargets(task)[, 1L])
+    survAUC::UnoC(Surv.rsp = surv.train, Surv.rsp.new = getPredictionTruth(pred), time = max.time, lpnew = y)
+  },
+  extra.args = list(max.time = NULL)
+)
+
+#' @export iauc.uno
+#' @rdname measures
+#' @format none
+#' @references
+#' H. Uno et al.
+#' *Evaluating Prediction Rules for T-Year Survivors with Censored Regression Models*
+#' Journal of the American Statistical Association 102, no. 478 (2007): 527-37. <http://www.jstor.org/stable/27639883>.
+iauc.uno = makeMeasure(id = "iauc.uno", minimize = FALSE, best = 1, worst = 0,
+  properties = c("surv", "req.pred", "req.truth", "req.model", "req.task"),
+  name = "Uno's estimator of cumulative AUC for right censored time-to-event data",
+  note = "To set an upper time limit, set argument max.time (defaults to max time in complete task). Implemented in survAUC::AUC.uno.",
+  fun = function(task, model, pred, feats, extra.args) {
+    requirePackages("_survAUC")
+    max.time = assertNumber(extra.args$max.time, null.ok = TRUE) %??% max(getTaskTargets(task)[, 1L])
+    times = seq(from = 0, to = max.time, length.out = extra.args$resolution)
+    surv.train = getTaskTargets(task, recode.target = "surv")[model$subset]
+    y = getPredictionResponse(pred)
+    if (anyMissing(y))
+      return(NA_real_)
+    survAUC::AUC.uno(Surv.rsp = surv.train, Surv.rsp.new = getPredictionTruth(pred), times = times, lpnew = y)$iauc
+  },
+  extra.args = list(max.time = NULL, resolution = 1000L)
+)
+
+#' @export ibrier
+#' @rdname measures
+#' @format none
+ibrier = makeMeasure(id = "ibrier", minimize = TRUE, best = 0, worst = 1,
+  properties = c("surv", "req.truth", "req.model", "req.task"),
+  name = "Integrated brier score using Kaplan-Meier estimator for weighting",
+  note = "To set an upper time limit, set argument max.time (defaults to max time in test data). Implemented in pec::pec",
+  fun = function(task, model, pred, feats, extra.args) {
+    requirePackages(c("survival", "pec"))
+    targets = getTaskTargets(task)
+    tn = getTaskTargetNames(task)
+    f = as.formula(sprintf("Surv(%s, %s) ~ 1", tn[1L], tn[2L]))
+    newdata = getTaskData(task)[model$subset, ]
+    max.time = extra.args$max.time %??% max(newdata[[tn[1L]]])
+    grid = seq(0, max.time, length.out = extra.args$resolution)
+
+    probs = predictSurvProb(model$learner.model, newdata = newdata, times = grid)
+    perror = pec(probs, f, data = newdata[, tn], times = grid, exact = FALSE, exactness = 99L,
+      maxtime = max.time, verbose = FALSE)
+
+    # FIXME: what is the difference between reference and matrix?
+    # FIXME: this might be the wrong number!
+    crps(perror, times = max.time)[1L, ]
+  },
+  extra.args = list(max.time = NULL, resolution = 1000L)
+)
+
 ###############################################################################
 ### cost-sensitive ###
 ###############################################################################
@@ -1418,7 +1510,7 @@ dunn = makeMeasure(id = "dunn", minimize = FALSE, best = Inf, worst = 0,
 #' @export G1
 #' @rdname measures
 #' @format none
-G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,
+G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,  # nolint
   properties = c("cluster", "req.pred", "req.feats"),
   name = "Calinski-Harabasz pseudo F statistic",
   note = "Defined as ratio of between-cluster variance to within cluster variance. See `?clusterSim::index.G1`.",
@@ -1432,7 +1524,7 @@ G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,
 #' @export G2
 #' @rdname measures
 #' @format none
-G2 = makeMeasure(id = "G2", minimize = FALSE, best = Inf, worst = 0,
+G2 = makeMeasure(id = "G2", minimize = FALSE, best = 1, worst = 0,  # nolint
   properties = c("cluster", "req.pred", "req.feats"),
   name = "Baker and Hubert adaptation of Goodman-Kruskal's gamma statistic",
   note = "Defined as: (number of concordant comparisons - number of discordant comparisons) / (number of concordant comparisons + number of discordant comparisons). See `?clusterSim::index.G2`.",
