@@ -35,12 +35,12 @@ tuneIrace = function(learner, task, resampling, measures, par.set, control, opt.
   tuner.config = c(list(targetRunnerParallel = targetRunnerParallel,
     instances = instances, logFile = log.file), control$extra.args)
   g = if (show.irace.output) identity else capture.output
-  g(or <- irace::irace(scenario = tuner.config, parameters = parameters))
+  g({or = irace::irace(scenario = tuner.config, parameters = parameters)})
   unlink(log.file)
   if (nrow(or) == 0L)
     stop("irace produced no result, possibly the budget was set too low?")
   # get best configuarion
-  x1 = as.list(irace::removeConfigurationsMetaData(or[1L,]))
+  x1 = as.list(irace::removeConfigurationsMetaData(or[1L, ]))
   # we need chars, not factors / logicals, so we can match 'x'
   d = convertDfCols(as.data.frame(opt.path), logicals.as.factor = TRUE)
   d = convertDfCols(d, factors.as.char = TRUE)
