@@ -14,14 +14,14 @@ test_that("classif_gbm", {
 
   mydata = binaryclass.train
   mydata[, binaryclass.target] = as.numeric(mydata[, binaryclass.target] ==  getTaskDesc(binaryclass.task)$positive)
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(binaryclass.formula, data = mydata, distribution = "bernoulli")
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
-    capture.output(
-      m <- do.call(gbm::gbm, pars)
-    )
+    capture.output({
+      m = do.call(gbm::gbm, pars)
+    })
     set.seed(getOption("mlr.debug.seed"))
     p = gbm::predict.gbm(m, newdata = binaryclass.test, n.trees = length(m$trees), type = "response")
     old.probs.list[[i]] = p
@@ -35,7 +35,7 @@ test_that("classif_gbm", {
   set.seed(getOption("mlr.debug.seed"))
   m = gbm::gbm(multiclass.formula, data = multiclass.train, n.trees = 300, interaction.depth = 2, distribution = "multinomial")
   p = gbm::predict.gbm(m, newdata = multiclass.test, n.trees = 300)
-  y = factor(apply(p[,,1],1, function(r) colnames(p)[which.max(r)]))
+  y = factor(apply(p[, , 1], 1, function(r) colnames(p)[which.max(r)]))
   testSimple("classif.gbm", multiclass.df, multiclass.target, multiclass.train.inds, y,
     parset = list(n.trees = 300, interaction.depth = 2, distribution = "multinomial"))
 })
