@@ -15,9 +15,9 @@ test_that("classif_h2orandomForest", {
   parset.list = lapply(parset.list, function(x) c(x, seed = debug.seed))
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
-    parset = c(parset,list(x = colnames(binaryclass.train[, -binaryclass.class.col]),
+    parset = c(parset, list(x = colnames(binaryclass.train[, -binaryclass.class.col]),
       y = binaryclass.target,
       training_frame = h2o::as.h2o(binaryclass.train)))
     m = do.call(h2o::h2o.randomForest, parset)
@@ -27,3 +27,16 @@ test_that("classif_h2orandomForest", {
   testProbParsets("classif.h2o.randomForest", binaryclass.df, binaryclass.target,
     binaryclass.train.inds, old.probs.list, parset.list)
 })
+
+test_that("class names are integers and probabilities predicted (#1787)", {
+  df = data.frame(matrix(runif(100, 0, 1), 100, 9))
+  classx = factor(sample(c(0, 1), 100, replace = TRUE))
+  df = cbind(classx, df)
+
+  classif.task = makeClassifTask(id = "example", data = df, target = "classx")
+  gb.lrn  = makeLearner("classif.h2o.randomForest", predict.type = "prob")
+  rdesc = makeResampleDesc("CV", iters = 3, stratify = TRUE)
+  rin = makeResampleInstance(rdesc, task = classif.task)
+  r = resample(gb.lrn, classif.task, rin)
+  expect_false(is.null(r$pred))
+})
