@@ -12,7 +12,7 @@ test_that("cluster_cmeans", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     set.seed(getOption("mlr.debug.seed"))
     m = e1071::cmeans(noclass.train, centers = centers)
@@ -32,7 +32,7 @@ test_that("cluster_cmeans", {
   m = train(lrn, task = makeClusterTask(data = noclass.train))
   pp = as.matrix(predict(m, newdata = noclass.test)$data)
 
-  expect_equal(getMaxIndexOfRows(p), pp[,1], check.attributes = FALSE)
-  expect_equal(p[,1], pp[,2], check.attributes = FALSE)
-  expect_equal(p[,2], pp[,3], check.attributes = FALSE)
+  expect_equal(getMaxIndexOfRows(p), pp[, 1], check.attributes = FALSE)
+  expect_equal(p[, 1], pp[, 2], check.attributes = FALSE)
+  expect_equal(p[, 2], pp[, 3], check.attributes = FALSE)
 })
