@@ -11,7 +11,7 @@ test_that("cluster_kmeans", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     if (is.null(parset$centers)) parset$centers = 2L
     set.seed(getOption("mlr.debug.seed"))
@@ -33,7 +33,7 @@ test_that("cluster_kmeans", {
   m = train(lrn, task = makeClusterTask(data = noclass.train))
   pp = as.matrix(predict(m, newdata = noclass.test)$data)
 
-  expect_equal(getMaxIndexOfRows(p), pp[,1], check.attributes = FALSE)
-  expect_equal(p[,1], pp[,2], check.attributes = FALSE)
-  expect_equal(p[,2], pp[,3], check.attributes = FALSE)
+  expect_equal(getMaxIndexOfRows(p), pp[, 1], check.attributes = FALSE)
+  expect_equal(p[, 1], pp[, 2], check.attributes = FALSE)
+  expect_equal(p[, 2], pp[, 3], check.attributes = FALSE)
 })
