@@ -10,7 +10,7 @@ test_that("regr_IBk", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     ctrl = do.call(RWeka::Weka_control, parset)
     pars = list(regr.formula, data = regr.train)
