@@ -11,7 +11,7 @@ test_that("regr_cvglmnet", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     x = regr.train
     y = x[, regr.class.col]
