@@ -1,9 +1,9 @@
 context("regr_gausspr")
 
 test_that("regr_gausspr", {
-  
+
   requirePackages("kernlab", default.method = "load")
-  
+
   parset.list = list(
     list(),
     list(kernel = "splinedot"),
@@ -11,8 +11,8 @@ test_that("regr_gausspr", {
   )
 
   old.predicts.list = list()
-  
-  for (i in 1:length(parset.list)) {
+
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(regr.formula, data = regr.train)
     pars = c(pars, parset)
@@ -21,7 +21,7 @@ test_that("regr_gausspr", {
       m = do.call(kernlab::gausspr, pars)
     })
     p = kernlab::predict(m, newdata = regr.test)
-    old.predicts.list[[i]] = p[,1]
+    old.predicts.list[[i]] = p[, 1]
   }
   testSimpleParsets("regr.gausspr", regr.df, regr.target, regr.train.inds,
     old.predicts.list, parset.list)
