@@ -1,6 +1,6 @@
 context("surv_ranger")
 
-## TODO: Proper test required when predictions working
+## FIXME: Proper test required when predictions working
 test_that("surv_ranger", {
   requirePackagesOrSkip(c("survival", "ranger"), default.method = "load")
 
@@ -14,13 +14,14 @@ test_that("surv_ranger", {
   expect_is(p, "PredictionSurv")
 
   parset.list = list(
-    list(num.trees = 10)
+    list(),
+    list(num.trees = 10L)
   )
 
   old.predicts.list = list()
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
-    pars = list(formula = surv.formula, data = surv.train, write.forest = TRUE, respect.unordered.factors = TRUE)
+    pars = list(formula = surv.formula, data = surv.train, respect.unordered.factors = TRUE)
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     m = do.call(ranger::ranger, pars)
